import request from '@/utils/request'

// 查询资产调整列表
export function listAdjustment(query) {
  return request({
    url: '/asset/adjustment/list',
    method: 'get',
    params: query
  })
}

// 查询资产调整详细
export function getAdjustment(id) {
  return request({
    url: '/asset/adjustment/' + id,
    method: 'get'
  })
}

// 新增资产调整
export function addAdjustment(data) {
  return request({
    url: '/asset/adjustment',
    method: 'post',
    data: data
  })
}

// 提交资产调整
export function submitAdjustment(data) {
  return request({
    url: '/asset/adjustment/submit',
    method: 'put',
    data: data
  })
}


// 审核资产调整
export function auditAdjustment(data) {
  return request({
    url: '/asset/adjustment/audit',
    method: 'put',
    data: data
  })
}

// 修改资产调整
export function updateAdjustment(data) {
  return request({
    url: '/asset/adjustment',
    method: 'put',
    data: data
  })
}

// 删除资产调整
export function delAdjustment(id) {
  return request({
    url: '/asset/adjustment/' + id,
    method: 'delete'
  })
}
